pub enum PointerBitmapTarget {
Software,
Accelerated,
}Expand description
Pointer bitmap rendering target. Defines properties and format of the decoded bitmap.
Variants
Software
Software rendering target will produce RGBA bitmaps with premultiplied alpha.
Colors with alpha channel set to 0x00 are always invisible no matter their color component. We could take advantage of that, and use a special color to represent inverted pixels. [0xFF, 0xFF, 0xFF, 0x00] is used for such purpose in software rendering mode.
Accelerated
Accelerated rendering target will produce RGBA bitmaps with non-premultiplied alpha. Inverted pixels will be rendered following the check pattern.